@@ -6,7 +6,7 @@ test_that("Default", {
 
   tagdropBtn <- dropdownButton(
     "Your contents goes here ! You can pass several elements",
-    circle = TRUE, status = "danger", icon = shiny::icon("gear"), width = "300px",
+    circle = TRUE, status = "danger", icon = shiny::icon("cog"), width = "300px",
     tooltip = tooltipOptions(title = "Click to see inputs !")
   )
 
@@ -18,9 +18,9 @@ test_that("InputId", {
 
   tagdropBtn <- dropdownButton(
     "Your contents goes here ! You can pass several elements", inputId = "MYID",
-    circle = FALSE, status = "danger", icon = shiny::icon("gear"), width = "300px"
+    circle = FALSE, status = "danger", icon = shiny::icon("cog"), width = "300px"
   )
 
-  expect_identical(tagdropBtn$attribs$id, "dropdown-MYID")
+  expect_identical(tagdropBtn$attribs$id, "MYID_state")
   expect_identical(tagdropBtn$children[[1]]$attribs$id, "MYID")
 })
